.. currentmodule:: obspy.clients.filesystem
.. automodule:: obspy.clients.filesystem

    .. comment to end block

    Classes & Functions
    -------------------
    .. autosummary::
       :toctree: autogen
       :nosignatures:

       sds.Client
       tsindex.Client
       tsindex.Indexer
       tsindex.TSIndexDatabaseHandler

    .. comment to end block

    Modules
    -------
    .. autosummary::
       :toctree: autogen
       :nosignatures:

       sds
       tsindex

    .. comment to end block
